GenCon Milwaukee, Wisconsin August 13th 2000 Christian King Crypt (12 cards, min=12, max=32, avg=5.17) ------------------------------------------ 2x Gratiano 8 DOM OBT obf pot priscus Lasombra:2 2x Guido Lucciano 5 OBT dom obf Lasombra:2 2x Ignacio, The Black Priest 4 dom obt pot Lasombra:2 2x Ramiro 4 dom obt vic Lasombra:2 1x Angelica, The Canonicus 10 DOM OBT POT cel obf cardinal Lasombra:2 1x Aurora Van Brande, Paladin 6 OBT dom for pot Lasombra:2 1x Aaron Duggan, Cameron's Toady 2 obt Lasombra:2 1x Mitchell, The Headhunter 2 obt pot Pander:2 Library (91 cards) Master (23) 1x Archon Investigation 4x Blood Doll 3x Dominate 3x Elysian Fields 2x Elysium: The Arboretum 2x Minion Tap 2x Obtenebration 3x Political Hunting Ground 2x Slave Auction 1x Sudden Reversal Action (7) 1x Bum's Rush 6x Govern the Unaligned Equipment (4) 4x Leather Jacket Action Modifier (24) 7x Bonding 6x Conditioning 8x Shadow Play 3x Shroud of Night Reaction (22) 5x Deflection 5x Eyes of the Night 6x Redirection 6x Wake with Evening's Freshness Combat (11) 3x Arms of the Abyss 3x Entombment 5x Shadow Body